gchecky.model.shopping_cart_t

Package gchecky :: Module model :: Class shopping_cart_t |
[hide private]
[frames] | no frames]

# Class shopping_cart_t

source code

    object --+
             |
     gxml.Node --+
                 |
                shopping_cart_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| expiration = `Timestamp:PATH(cart-expiration/good-until-date):OPT`
| items = `List:PATH(items):RE`...``
| merchant_private_data = `Any:PATH(merchant-private-data):OPT`
| _fields = ``{``'``expiration``'``:` Timestamp:PATH(cart-expiration/good-u`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### items Value:
      List:PATH(items):REQ:[
          Node:PATH(item):REQ:{ item_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'expiration': Timestamp:PATH(cart-expiration/good-until-date):OPT,
       'items': List:PATH(items):REQ:[
          Node:PATH(item):REQ:{ item_t }
      ],
       'merchant_private_data': Any:PATH(merchant-private-data):OPT}